@@ -325,8 +325,6 @@ class WebalbumDir(make.FileMakeObject):
             self.medias.append(media_task)
             self.add_dependency(media_task)
 
-        self.dirzip = None
-
         self.index_pages = []
 
         if not self.should_be_flattened():
@@ -419,7 +417,7 @@ class WebalbumDir(make.FileMakeObject):
 
         if self.config.getboolean('webgal', 'dirzip')\
         and self.source_dir.get_media_count() > 1:
-            self.dirzip = genfile.WebalbumArchive(dir)
+            self.dirzip = genfile.WebalbumArchive(self)
             self.add_dependency(self.dirzip)
         else:
             self.dirzip = None
