@@ -18,6 +18,7 @@
 
 import os
 import locale
+import logging
 import zipfile
 
 import make
@@ -36,9 +37,8 @@ class MediaOriginal(make.FileCopy):
         make.FileCopy.__init__(self, source_media.path, self.path)
 
     def build(self):
-        self.dir.album.log("  CP %s" % os.path.basename(self.path),
-                           'info')
-        self.dir.album.log("(%s)" % self.path)
+        logging.info("  CP %s" % os.path.basename(self.path))
+        logging.debug("(%s)" % self.path)
         make.FileCopy.build(self)
 
 
@@ -55,9 +55,8 @@ class SymlinkMediaOriginal(make.FileSymlink):
         make.FileSymlink.__init__(self, source_media.path, self.path)
 
     def build(self):
-        self.dir.album.log("  SYMLINK %s" % os.path.basename(self.path),
-                           'info')
-        self.dir.album.log("(%s)" % self.path)
+        logging.info("  SYMLINK %s" % os.path.basename(self.path))
+        logging.debug("(%s)" % self.path)
         make.FileSymlink.build(self)
 
 
@@ -68,14 +67,15 @@ class WebalbumFile(make.FileMakeObject):
         self.dir = dir
         self.path = path
 
-    def _rel_path(self, dir=None):
-        rel_path = os.path.basename(self.path)
+    def rel_path(self, dir):
+        '''
+        Returns the path of the current object relative to the supplied dir
+        object argument.
+        '''
         if dir is None or dir is self.dir:
-            return rel_path
+            return os.path.basename(self.path)
         else:
-            dir_in = dir.source_dir
-            rel_dir_in = self.dir.source_dir.rel_path(dir_in)
-            return os.path.join(rel_dir_in, rel_path)
+            return dir.rel_path(self.path)
 
 
 class WebalbumArchive(WebalbumFile):
@@ -85,10 +85,6 @@ class WebalbumArchive(WebalbumFile):
                                  webgal_dir.source_dir.name + '.zip')
         WebalbumFile.__init__(self, self.path, webgal_dir)
 
-        self.album = self.dir.album
-
-        self.dir.dirzip = self
-
         self.add_dependency(self.dir.source_dir)
 
         self.pics = map(lambda x: os.path.join(self.dir.source_dir.path, x),
@@ -97,9 +93,9 @@ class WebalbumArchive(WebalbumFile):
             self.add_file_dependency(pic)
 
     def build(self):
-        zip_rel_path = self._rel_path(self.dir.flattening_dir)
-        self.album.log(_("  ZIP %s") % zip_rel_path, 'info')
-        self.album.log("(%s)" % self.path)
+        zip_rel_path = self.rel_path(self.dir.flattening_dir)
+        logging.info(_("  ZIP %s") % zip_rel_path)
+        logging.debug("(%s)" % self.path)
 
         archive = zipfile.ZipFile(self.path, mode='w')
         for pic in self.pics:
@@ -116,14 +112,12 @@ class WebalbumArchive(WebalbumFile):
 
 class SharedFileCopy(make.FileCopy):
 
-    def __init__(self, album, src, dst):
+    def __init__(self, src, dst):
         make.FileCopy.__init__(self, src, dst)
-        self.album = album
 
     def build(self):
-        self.album.log(_("CP %%SHAREDDIR%%/%s") %\
-                       os.path.basename(self.dst), 'info')
-        self.album.log("(%s)" % self.dst)
+        logging.info(_("CP %%SHAREDDIR%%/%s") % os.path.basename(self.dst))
+        logging.debug("(%s)" % self.dst)
         make.FileCopy.build(self)
 
 
