@@ -16,9 +16,9 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import os, locale
+import logging
 import codecs
 import datetime
-import Image
 
 from lazygal import pyexiv2api as pyexiv2
 from lazygal import make
@@ -154,7 +154,7 @@ class ImageInfoTags(object):
         '''
 
         try:
-            return self.get_tag_value('Exif.Pentax.LensType')
+            return self._metadata['Exif.Pentax.LensType'].human_value.strip()
         except (IndexError, ValueError, KeyError):
             try:
                 ret = self._metadata['Exif.Nikon3.Lens'].human_value.strip()
@@ -166,7 +166,7 @@ class ImageInfoTags(object):
                     return '%s %s' % (ret, ret2)
             except (IndexError, ValueError, KeyError):
                 try:
-                    return self.get_tag_value('Exif.Minolta.LensID')
+                    return self._metadata['Exif.Minolta.LensID'].human_value.strip()
                 except (IndexError, ValueError, KeyError):
                     return ''
 
@@ -198,13 +198,17 @@ class ImageInfoTags(object):
             return float(val.numerator) / float(val.denominator)
 
     def _fallback_to_encoding(self, encoded_string, encoding='utf-8'):
+        if type(encoded_string) is unicode: return encoded_string
         try:
             return encoded_string.decode(encoding)
         except UnicodeDecodeError:
             return encoded_string.decode(encoding, 'replace')
 
     def get_exif_usercomment(self):
-        return self.get_tag_value('Exif.Photo.UserComment').strip(' \0\x00')
+        ret = self.get_tag_value('Exif.Photo.UserComment').strip(' \0\x00')
+        if ret == 'User comments':
+            return ''
+        return ret
 
     def get_file_comment(self):
         fmd = FileMetadata(self.image_path + FILE_METADATA_MEDIA_SUFFIX)
@@ -215,6 +219,7 @@ class ImageInfoTags(object):
             ret = self.get_file_comment()
             if ret is None:
                 ret = self.get_exif_usercomment()
+                ret = self._fallback_to_encoding(ret)
                 if ret == '':
                     raise ValueError
         except (ValueError, KeyError):
@@ -231,7 +236,7 @@ class ImageInfoTags(object):
 
     def get_flash(self):
         try:
-            return self.get_tag_value('Exif.Photo.Flash')
+            return self._metadata['Exif.Photo.Flash'].human_value
         except KeyError:
             return ''
 
@@ -283,10 +288,11 @@ class ImageInfoTags(object):
 
         try:
             try:
-                iwidth = float(str(self._metadata['Exif.Photo.ImageWidth']))
-            except IndexError:
-                iwidth = float(str(self._metadata['Exif.Photo.PixelXDimension']))
-            fresunit = str(self._metadata['Exif.Photo.FocalPlaneResolutionUnit'])
+                iwidth = self.get_exif_float_value('Exif.Photo.ImageWidth')
+            except (IndexError, KeyError):
+                iwidth = self.get_exif_float_value('Exif.Photo.PixelXDimension')
+
+            fresunit = str(self._metadata['Exif.Photo.FocalPlaneResolutionUnit'].value)
             factors = {'1': 25.4, '2': 25.4, '3': 10, '4': 1, '5': 0.001}
             try:
                 fresfactor = factors[fresunit]
@@ -300,18 +306,24 @@ class ImageInfoTags(object):
                 return ''
 
             foclength = self.get_exif_float_value('Exif.Photo.FocalLength')
-            lenstr = '%.01f' % (foclength / ccdwidth * 36 + 0.5)
+            try:
+                lenstr = '%.01f' % (foclength / ccdwidth * 36 + 0.5)
+            except ZeroDivisionError:
+                raise ValueError
 
             flen += _(' (35 mm equivalent: %s mm)') % lenstr
-        except (IndexError, KeyError):
+        except (IndexError, KeyError, ValueError):
             return flen
 
         return flen
 
     def get_jpeg_comment(self):
         try:
-            return self._fallback_to_encoding(self._metadata.comment.strip(' '))
-        except AttributeError:
+            comment = self._metadata.comment.strip(' ')
+            if '\x00' in comment:
+                raise ValueError # ignore broken JPEG comments
+            return self._fallback_to_encoding(comment)
+        except (AttributeError, ValueError):
             return ''
 
     def get_authorship(self):
@@ -374,11 +386,14 @@ class DirectoryMetadata(make.GroupTask):
                         data = data[1:]
                     if data[-1] == '"':
                         data = data[:-1]
+                    data = data.decode(locale.getpreferredencoding())
+
                     if tag == 'album_picture':
                         if subdir is not None:
                             data = os.path.join(subdir, data)
                         data = os.path.join(self.dir_path, data)
-                    metadata[tag] = data.decode(locale.getpreferredencoding())
+
+                    metadata[tag] = data
                     break
 
         return metadata
@@ -462,9 +477,9 @@ class DefaultMetadata(make.FileMakeObject):
         md_data = md.get(None, self.source_dir)
         if 'album_description' in md_data.keys()\
         or 'album_name' in md_data.keys():
-            self.album.log(_("  SKIPPED because metadata exists."))
+            logging.debug(_("  SKIPPED because metadata exists."))
         elif self.source_dir.get_all_medias_count() < 1:
-            self.album.log(_("  SKIPPED because directory does not contain images."))
+            logging.debug(_("  SKIPPED because directory does not contain images."))
         else:
             self.generate(md_data)
 
@@ -473,7 +488,7 @@ class DefaultMetadata(make.FileMakeObject):
         Generates new metadata file with default values.
         '''
 
-        self.album.log(_("GEN %s") % self._path, 'info')
+        logging.info(_("GEN %s") % self._path)
 
         f = file(self._path, 'w')
         f.write(codecs.BOM_UTF8)
