@@ -16,9 +16,12 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import os, sys, datetime, time
+import locale
+import logging
 import Image
 
-from lazygal import make, metadata
+from lazygal import pathutils, make, metadata
+from lazygal import mediautils
 
 
 SOURCEDIR_CONFIGFILE = '.lazygal'
@@ -29,46 +32,19 @@ class File(make.FileSimpleDependency):
     def __init__(self, path, album):
         make.FileSimpleDependency.__init__(self, path)
 
-        self.path = self._path_to_unicode(path)
+        self.path = pathutils.path2unicode(path)
         self.album = album
         self.filename = os.path.basename(self.path)
         self.name, self.extension = os.path.splitext(self.filename)
 
-    def _path_to_unicode(self, path):
-        if type(path) is unicode:
-            return path
-        else:
-            return path.decode(sys.getfilesystemencoding())
-
     def strip_root(self, path=None):
-        found = False
-        album_path = ""
-
         if not path:
-            head = self.path
-        else:
-            head = path
+            path = self.path
 
-        while not found:
-            if head == self.album.source_dir:
-                found = True
-            elif head == "/":
-                raise Exception(_("Root not found"))
-            else:
-                head, tail = os.path.split(head)
-                if album_path == "":
-                    album_path = tail
-                else:
-                    album_path = os.path.join(tail, album_path)
-
-        return album_path
+        return pathutils.relative_path(self.album.source_dir, path)
 
     def rel_root(self):
-        if os.path.isdir(self.path):
-            path = self.path
-        else:
-            path = os.path.dirname(self.path)
-        return self.rel_path(path, self.album.source_dir)
+        return pathutils.relative_path(self.path, self.album.source_dir)
 
     def rel_path(self, from_dir, path=None):
         try:
@@ -79,36 +55,18 @@ class File(make.FileSimpleDependency):
         if path is None:
             path = self.path
 
-        if not os.path.isdir(path):
-            path, fn = os.path.split(path)
-        else:
-            fn = None
-
-        rel_path = ""
-        common_path = from_dir
-        while common_path != self.album.source_dir\
-        and not self.is_subdir_of(common_path, path):
-            common_path, tail = os.path.split(common_path)
-            rel_path = os.path.join('..', rel_path)
-            if common_path == '/':
-                raise Exception(_("Root not found"))
-
-        if self.is_subdir_of(common_path, path):
-            rel_path = os.path.join(rel_path, path[len(common_path)+1:])
-
-        if fn:
-            rel_path = os.path.join(rel_path, fn)
-
-        return rel_path
+        return pathutils.relative_path(from_dir, path)
 
     def is_subdir_of(self, dir, path=None):
         if path is None:
             path = self.path
 
         try:
-            return path.startswith(dir.path)
+            dir_path = dir.path
         except AttributeError:
-            return path.startswith(dir)
+            dir_path = dir
+
+        return pathutils.is_subdir_of(dir_path, path)
 
     def get_album_level(self, path=None):
         if path is None: path = self.path
@@ -132,7 +90,7 @@ class File(make.FileSimpleDependency):
         head = self.strip_root()
         while head != '':
             head, tail = os.path.split(head)
-            if tail in Directory.SKIPPED_DIRS:
+            if tail in File.SKIPPED_DIRS:
                 return True
         return False
 
@@ -143,7 +101,7 @@ class File(make.FileSimpleDependency):
         return int(self.get_mtime() - other_file.get_mtime())
 
     def compare_filename(self, other_file):
-        return cmp(self.filename, other_file.filename)
+        return locale.strcoll(self.filename, other_file.filename)
 
 
 class MediaFile(File):
@@ -237,29 +195,28 @@ class ImageFile(MediaFile):
 class VideoFile(MediaFile):
     type = 'video'
 
+    def get_size(self):
+        inspector = mediautils.GstVideoInfo(self.path)
+        inspector.inspect()
+        return inspector.videowidth, inspector.videoheight
+
     def has_reliable_date(self):
         return False
 
     def get_date_taken(self):
         return self.get_datetime()
 
-    def get_size(self, path=None):
-        size = (400, 300)
-        if path:
-            # Assume for now this is a thumb
-            return self.album.newsizers['thumb'].dest_size(size)
-        else:
-            return size
-
 
 class MediaHandler(object):
 
     FORMATS = { '.jpeg' : ImageFile,
                 '.jpg'  : ImageFile,
+                '.png'  : ImageFile,
                 '.mov'  : VideoFile,
                 '.avi'  : VideoFile,
                 '.mp4'  : VideoFile,
                 '.3gp'  : VideoFile,
+                '.webm' : VideoFile,
               }
 
     def __init__(self, album):
@@ -275,7 +232,7 @@ class MediaHandler(object):
         extension = extension.lower()
         if extension in MediaHandler.FORMATS.keys():
             media_class = MediaHandler.FORMATS[extension]
-            if media_class == VideoFile and not self.album.get_transcoder():
+            if media_class == VideoFile and not mediautils.HAVE_GST:
                 return None
             return media_class(path, self.album)
         else:
@@ -292,7 +249,7 @@ class Directory(File):
         self.extension = None
 
         self.subdirs = subdirs
-        self.filenames = map(self._path_to_unicode, filenames)
+        self.filenames = map(pathutils.path2unicode, filenames)
 
         self.human_name = self.album._str_humanize(self.name)
 
@@ -307,9 +264,9 @@ class Directory(File):
                 self.medias.append(media)
             elif not self.is_metadata(filename)and\
                  filename != SOURCEDIR_CONFIGFILE:
-                self.album.log(_("  Ignoring %s, format not supported.")\
-                               % filename, 'info')
-                self.album.log("(%s)" % os.path.join(self.path, filename))
+                logging.info(_("  Ignoring %s, format not supported.")\
+                             % filename)
+                logging.debug("(%s)" % os.path.join(self.path, filename))
 
         self.metadata = metadata.DirectoryMetadata(self.path)
         md = self.metadata.get(None, self)
@@ -328,7 +285,7 @@ class Directory(File):
             self.album_picture = None
 
     def is_album_root(self):
-        return self.path == self._path_to_unicode(self.album.source_dir)
+        return self.path == pathutils.path2unicode(self.album.source_dir)
 
     def parent_paths(self):
         parent_paths = [self.path]
@@ -395,18 +352,36 @@ class Directory(File):
             all_subdirs.extend(subdir.get_all_subdirs())
         return all_subdirs
 
-    def compare_latest_exif(self, other_gallery):
-        date1 = max([time.mktime(m.get_date_taken().timetuple())\
-                     for m in self.get_all_medias()])
+    def latest_media_stamp(self, hint=None):
+        '''
+        Returns the latest media date:
+            - first considering all pics that have an EXIF date
+            - if none have a reliable date, use file mtimes.
+        `hint` stops processing if one of the found values is higher. This is
+        to speed up compare_latest_exif().
+        '''
+        all_medias = self.get_all_medias()
+        media_stamp_max = None
+        for m in all_medias:
+            if m.has_reliable_date():
+                media_stamp = time.mktime(m.get_date_taken().timetuple())
+                if media_stamp_max is None or media_stamp > media_stamp_max:
+                    media_stamp_max = media_stamp
+                    if hint is not None and media_stamp_max > hint:
+                        return media_stamp_max
 
-        date2 = None
-        for m in other_gallery.get_all_medias():
-            m_stamp = time.mktime(m.get_date_taken().timetuple())
-            if m_stamp > date2 or date2 is None:
-                date2 = m_stamp
-            # Stop here if we already found a media with later date
-            if date2 > date1:
-                return int(date1 - date2)
+        if media_stamp_max is None:
+            # none of the media had a reliable date, use mtime instead
+            for m in all_medias:
+                media_stamp = time.mktime(m.get_mtime().timetuple())
+                if media_stamp_max is None or media_stamp > media_stamp_max:
+                    media_stamp_max = media_stamp
+
+        return media_stamp_max
+
+    def compare_latest_exif(self, other_gallery):
+        date1 = self.latest_media_stamp()
+        date2 = other_gallery.latest_media_stamp(date1)
 
         return int(date1 - date2)
 
