@@ -142,6 +142,20 @@ class TestFileMetadata(LazygalTest):
         im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
         self.assertEqual(im_md.get_lens_name(), '70-200mm F2.8 D G')
 
+        sample = 'sample-model-pentax1.jpg'
+        im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
+        self.assertEqual(im_md.get_lens_name(), 'smc PENTAX-DA 18-55mm F3.5-5.6 AL WR')
+
+    def test_flash(self):
+        sample = 'sample-model-pentax1.jpg'
+        im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
+        self.assertEqual(im_md.get_flash(), 'Yes, auto')
+
+    def test_focal_length(self):
+        sample = 'sample-model-pentax1.jpg'
+        im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
+        self.assertEqual(im_md.get_focal_length(), '18.0 mm (35 mm equivalent: 27.0 mm)')
+
 
 if __name__ == '__main__':
     unittest.main()
